Ext.define('DSS.addon.EventMailer', {

    extend : 'DSS.addon.Framework',

    config : {
        appName : 'Messages',
        appId : 'hleedit',
        appVersion : '1.0.0.0',
        appIcon : 'default_icon.png',
    },

    getHelp : function() {
        return Ext.create('Ext.Component', {
            loader : {
                url : 'locale/' + dss.staticDataModel.activeLanguage + '/help.html',
                autoLoad : true,
                disableCaching : false
            }
        });
    },

    getContent : function() {
        var me=this;
        
        var oConfig={
                defaultSortCol:'name',
                disabledProperty:'disabled',
                storeConfig: {
                    storeId : 'emailStore',
                    fields : [ {name:'disabled', sortType:'asBoolean'}, 
                               {name:'name', sortType:'asUCText'}, 
                               {name:'id'}, 
                               {name:'message', sortType:'asEmail'}, 
                               {name:'triggers', sortType:'asTrigger'}, 
                               { name: 'conditions',  sortType: 'asUCText' },
                               {name:'defaultFooter', sortType:'asBoolean'} ]
                },
                
                columns: [{
                    header : _('Active'),
                    dataIndex : 'disabled',
                    resizable : false,
                    xtype: 'disabledcolumn', 
                    width : 50
                }, {
                    header : _('Name'),
                    dataIndex : 'name',
                    xtype: 'textcolumn', 
                    width : 200
                }, {
                    header : _('Trigger'),
                    dataIndex : 'triggers', 
                    maintainFlex : true,
                    flex : 1,
                    xtype: 'triggercolumn'
                },{
                    header : _('Message'),
                    dataIndex : 'message',
                    xtype:'emailcolumn',
                    flex : 1
                },{
                    header: _('Conditions'),
                    dataIndex: 'conditions', // alibi index
                    xtype: 'conditioncolumn',
                    maintainFlex: true,
                    flex: 1,
                    customRendererOptions:{hideEnabled:true,hideWeekdays:false,hideGenericSystemStates:false,hideZoneStates:false,hideTimeframe:false,filterSystemState:[]}
                }],     
                buttonText: {
                    newButton: _('New message'),
                    editButton: _('Edit message'),
                    enableButton:_('Activate message'),
                    disableButton:_('Deactivate message'),
                    testButton: _('Test message'),
                    deleteButton: _('Delete message')
                },
                editorConfig:{
                    title : _('Messageproperties'),
                    staticControls : [{
                        type : 'text',
                        label : _('Name'),
                        id : 'name'
                    }, {
                        type : 'hidden',
                        label : _('id'),
                        id : 'id'
                    }],
                    tabControls :  [{
                        tabLabel : _('Trigger'),
                        tabDescription : _('Choose the triggering activity for the message. You can choose more than one activity as trigger.'),
                        content : [ {
                            type : 'TriggerConfigurator',
                            id : 'triggers',
                            flex : true
                        } ]
                    }, {
                        tabLabel : _('Conditions'),
                        content : []
                    }, {
                        tabLabel : _('Message'),
                        tabDescription : _('Provide the Message, which will be send.'),
                        content : [ {
                            type : 'MessageControl',
                            id : 'message',
                            title : _('Message'),
                            flex : true
                        }/*, {
                            type : 'checkbox',
                            id : 'defaultFooter',
                            label : "Standardtext mit Beschreibung des ausl&ouml;senden Events anf&uuml;gen"
                        } */]
                    } , {
                        tabLabel : _('Conditions'),
                        tabDescription : _('Choose the conditions.'),
                        content : [{
                            type : 'ConditionConfigurator',
                            id : 'conditions',
                            order:[{type:'state',name:'daynight'},{type:'timeframe'},{type:'weekdays'},{type:'state',name:'presence'},{type:'state',name:'holiday'},{type:'zonestate'}],
                            flex : true
                        }]
                    }]
                },
                listeners: {
                    'loadDataStore':function (grid){
                        me.loadParameter(grid);
                    },
                    'saveEntry':function (grid,values){    
                        
                        dss.raiseEvent('event-mailer', {
                            actions : 'save',
                            value : Ext.JSON.encode(values)
                        })
                        me.waitAndReload(grid);
                    },
                    'enableEntry':function (grid,entry){
                        dss.raiseEvent('event-mailer', {
                            actions : 'enable',
                            id : entry.get('id')
                        });
                        me.waitAndReload(grid);
                     },
                    'disableEntry':function (grid,entry){
                        dss.raiseEvent('event-mailer', {
                            actions : 'disable',
                            id : entry.get('id')
                        })
                        me.waitAndReload(grid);
                    },
                    'deleteEntry':function (grid,entry){
                        dss.raiseEvent('event-mailer', {
                            actions : 'delete',
                            id : entry.get('id')
                        })
                        me.waitAndReload(grid);
                    },
                    'testEntry':function (grid,entry){
                        dss.raiseEvent('event-mailer', {
                            actions : 'test',
                            id : entry.get('id')
                        });
                    }
                }
        };
        
        return Ext.create('DSS.gridPanel', oConfig);
    },
    loadParameter : function(grid) {
        var sString = dss.ajaxSyncRequest('/json/property/query', {
            'query' : '/scripts/event-mailer/values/*(*)/*(*)/*(*)/*(*)'
        });
        var result = Ext.JSON.decode(sString);
        
        oResultObject=dss.parsePropertyQueryAnswer(result,[{name:'name',type:'simple'},
                                                           {name:'id',type:'simple'},
                                                           {name:'disabled',type:'condition/enabled'},
                                                           {name:'message', type:'message'},
                                                           {name:'triggers',type:'trigger'},
                                                           {name: 'conditions', type: 'condition'}]);    
        if (oResultObject!=null) {
            grid.loadParameter(oResultObject);
        }
    },
    waitAndReload : function(grid) {
        var me = this;
        var iSubscriptID = Math.floor(Math.random() * 100000000000);
        dss.ajaxSyncRequest('/json/event/subscribe', {
            subscriptionID : iSubscriptID,
            name : 'event-mailer-saved'
        });
        dss.ajaxAssyncRequestWithoutAnswer('/json/event/get', {
            subscriptionID : iSubscriptID,
            timeout : 60 * 1000
        }, function() {
            me.loadParameter(grid);
            dss.ajaxAssyncRequestWithoutAnswer('/json/event/unsubscribe', {
                subscriptionID : iSubscriptID,
                name : 'event-mailer-saved'
            });
        });
    }
});

Ext.onReady(function() {
    dss.buildUpLang(['locale/{languageSuffix}/event-mailer.po']);
    var EmailEdit = Ext.create('DSS.addon.EventMailer');
    EmailEdit.initPage();
});
